from checkov.cloudformation.checks.resource.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class EFSEncryption(BaseResourceValueCheck):
    def __init__(self):
        name = "Ensure EFS is securely encrypted"
        id = "CKV_AWS_42"
        supported_resources = ['AWS::EFS::FileSystem']
        categories = [CheckCategories.ENCRYPTION]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self):
        return 'Properties/Encrypted'


check = EFSEncryption()



from checkov.common.checks_infra.solvers.resource_solvers.not_exists_resource_solver import ExistsResourcerSolver  # noqa
from checkov.common.checks_infra.solvers.resource_solvers.not_exists_resource_solver import NotExistsResourcerSolver  # noqa



from __future__ import annotations

import logging
import re
from typing import Any, TYPE_CHECKING

from checkov.arm.graph_builder.graph_components.blocks import ArmBlock
from checkov.arm.utils import ArmElements, extract_resource_name_from_resource_id_func, \
    extract_resource_name_from_reference_func
from checkov.arm.graph_builder.variable_rendering.renderer import ArmVariableRenderer
from checkov.common.graph.graph_builder import CustomAttributes, Edge
from checkov.common.graph.graph_builder.local_graph import LocalGraph
from checkov.common.util.consts import START_LINE, END_LINE
from checkov.common.util.data_structures_utils import pickle_deepcopy

if TYPE_CHECKING:
    from checkov.common.graph.graph_builder.local_graph import _Block

DEPENDS_ON_FIELD = 'dependsOn'
RESOURCE_ID_FUNC = 'resourceId('
REFERENCE_FUNC = 'reference('


class ArmLocalGraph(LocalGraph[ArmBlock]):
    def __init__(self, definitions: dict[str, dict[str, Any]]) -> None:
        super().__init__()
        self.vertices: list[ArmBlock] = []
        self.definitions = definitions
        self.vertices_by_path_and_id: dict[tuple[str, str], int] = {}
        self.vertices_by_name: dict[str, int] = {}

    def build_graph(self, render_variables: bool = False) -> None:
        self._create_vertices()
        logging.warning(f"[ArmLocalGraph] created {len(self.vertices)} vertices")

        '''
            In order to resolve the resources names for the dependencies we need to render the variables first
            Examples: https://learn.microsoft.com/en-us/azure/azure-resource-manager/templates/resource-dependency
        '''

        self._create_vars_and_parameters_edges()
        if render_variables:
            renderer = ArmVariableRenderer(self)
            renderer.render_variables_from_local_graph()

        self._create_edges()
        logging.warning(f"[ArmLocalGraph] created {len(self.edges)} edges")

    def _create_vertices(self) -> None:
        for file_path, definition in self.definitions.items():
            self._create_parameter_vertices(file_path=file_path, parameters=definition.get(ArmElements.PARAMETERS))
            self._create_resource_vertices(file_path=file_path, resources=definition.get(ArmElements.RESOURCES))
            self._create_variables_vertices(file_path=file_path, variables=definition.get(ArmElements.VARIABLES))

        for i, vertex in enumerate(self.vertices):
            self.vertices_by_block_type[vertex.block_type].append(i)
            self.vertices_block_name_map[vertex.block_type][vertex.name].append(i)
            self.vertices_by_path_and_id[(vertex.path, vertex.id)] = i
            self.vertices_by_name[vertex.name] = i

            self.in_edges[i] = []
            self.out_edges[i] = []

    def _create_variables_vertices(self, file_path: str, variables: dict[str, dict[str, Any]] | None) -> None:
        if not variables:
            return

        for name, conf in variables.items():
            if name in [START_LINE, END_LINE]:
                continue
            if not isinstance(conf, dict) or "value" not in conf:
                full_conf = {"value": pickle_deepcopy(conf)}
            else:
                full_conf = conf
            config = pickle_deepcopy(full_conf)
            attributes = pickle_deepcopy(full_conf)

            self.vertices.append(
                ArmBlock(
                    name=name,
                    config=config,
                    path=file_path,
                    block_type=ArmElements.VARIABLES,
                    attributes=attributes,
                    id=f"{ArmElements.VARIABLES}.{name}",
                )
            )

    def _create_parameter_vertices(self, file_path: str, parameters: dict[str, dict[str, Any]] | None) -> None:
        if not parameters:
            return

        for name, config in parameters.items():
            if name in (START_LINE, END_LINE):
                continue
            if not isinstance(config, dict):
                logging.warning(f"[ArmLocalGraph] parameter {name} has wrong type {type(config)}")
                continue

            attributes = pickle_deepcopy(config)

            self.vertices.append(
                ArmBlock(
                    name=name,
                    config=config,
                    path=file_path,
                    block_type=ArmElements.PARAMETERS,
                    attributes=attributes,
                    id=f"{ArmElements.PARAMETERS}.{name}",
                )
            )

    def _create_resource_vertices(self, file_path: str, resources: list[dict[str, Any]] | None) -> None:
        if not resources:
            return

        for config in resources:
            if "type" not in config:
                # this can't be a real ARM resource without a "type" field
                return

            resource_name = config.get("name") or "unknown"
            resource_type = config["type"]

            attributes = pickle_deepcopy(config)
            attributes[CustomAttributes.RESOURCE_TYPE] = resource_type

            self.vertices.append(
                ArmBlock(
                    name=resource_name,
                    config=config,
                    path=file_path,
                    block_type=ArmElements.RESOURCES,
                    attributes=attributes,
                    id=f"{resource_type}.{resource_name}"
                )
            )

    def _create_edges(self) -> None:
        for origin_vertex_index, vertex in enumerate(self.vertices):
            if DEPENDS_ON_FIELD in vertex.attributes:
                self._create_explicit_edge(origin_vertex_index, vertex.name, vertex.attributes['dependsOn'])
            self._create_implicit_edges(origin_vertex_index, vertex.name, vertex.attributes)

    def _create_explicit_edge(self, origin_vertex_index: int, resource_name: str, deps: list[str]) -> None:
        for dep in deps:
            if RESOURCE_ID_FUNC in dep:
                processed_dep = extract_resource_name_from_resource_id_func(dep)
            else:
                processed_dep = dep.split('/')[-1]
            # Check if the processed dependency exists in the map
            if processed_dep in self.vertices_by_name:
                self._create_edge(processed_dep, origin_vertex_index, f'{resource_name}->{processed_dep}')
            else:
                # Dependency not found
                logging.warning(f"[ArmLocalGraph] resource dependency {processed_dep} defined in {dep} for resource"
                                f" {resource_name} not found")
                continue

    def _create_vars_and_parameters_edges(self) -> None:
        pattern = r"(variables|parameters)\('(\w+)'\)"
        for origin_vertex_index, vertex in enumerate(self.vertices):
            for attr_key, attr_value in vertex.attributes.items():
                if not isinstance(attr_value, str):
                    continue
                if ArmElements.VARIABLES in attr_value or ArmElements.PARAMETERS in attr_value:
                    matches = re.findall(pattern, attr_value)
                    for match in matches:
                        var_name = match[1]
                        self._create_edge(var_name, origin_vertex_index, attr_key)

    def _create_edge(self, element_name: str, origin_vertex_index: int, label: str) -> None:
        dest_vertex_index = self.vertices_by_name.get(element_name)
        if origin_vertex_index == dest_vertex_index or dest_vertex_index is None:
            return
        edge = Edge(origin_vertex_index, dest_vertex_index, label)
        self.edges.append(edge)
        self.out_edges[origin_vertex_index].append(edge)
        self.in_edges[dest_vertex_index].append(edge)

    def _create_implicit_edges(self, origin_vertex_index: int, resource_name: str, resource: dict[str, Any]) -> None:
        for value in resource.values():
            if isinstance(value, str):
                if REFERENCE_FUNC in value:
                    self._create_implicit_edge(origin_vertex_index, resource_name, value)

    def _create_implicit_edge(self, origin_vertex_index: int, resource_name: str, reference_string: str) -> None:
        dep_name = extract_resource_name_from_reference_func(reference_string)
        self._create_edge(dep_name, origin_vertex_index, f'{resource_name}->{dep_name}')

    def update_vertices_configs(self) -> None:
        # not used
        pass

    @staticmethod
    def update_vertex_config(
            vertex: _Block, changed_attributes: list[str] | dict[str, Any], has_dynamic_blocks: bool = False
    ) -> None:
        # not used
        pass

    def get_resources_types_in_graph(self) -> list[str]:
        # not used
        return []



from __future__ import annotations

from typing import Any, Dict

from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.arm.base_resource_check import BaseResourceCheck


class AzureSearchSLAIndex(BaseResourceCheck):
    def __init__(self) -> None:
        # Cognitive Search services support indexing and querying. Indexing is the process of loading content into
        # the service to make it searchable. Querying is the process where a client searches for content
        # by sending queries to the index.
        # Cognitive Search supports a configurable number of replicas. Having multiple replicas allows queries and
        # index updates to load balance across multiple replicas.
        #
        # To receive a Service Level Agreement (SLA) for Search index updates a minimum of 3 replicas is required.
        name = "Ensure that Azure Cognitive Search maintains SLA for index updates"
        id = "CKV_AZURE_208"
        supported_resources = ["Microsoft.Search/searchServices", ]
        categories = [CheckCategories.GENERAL_SECURITY, ]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf: Dict[str, Any]) -> CheckResult:
        properties = conf.get("properties", {})
        if not isinstance(properties, dict):
            return CheckResult.FAILED
        replica_count = properties.get("replicaCount")
        if replica_count and isinstance(replica_count, int):
            if replica_count >= 3:
                return CheckResult.PASSED
            else:
                return CheckResult.FAILED
        else:
            return CheckResult.FAILED


check = AzureSearchSLAIndex()



from __future__ import annotations

import os
from typing import TYPE_CHECKING, Any

from checkov.arm.graph_builder.local_graph import ArmLocalGraph
from checkov.arm.utils import get_scannable_file_paths, get_files_definitions
from checkov.common.graph.graph_builder.consts import GraphSource
from checkov.common.graph.graph_manager import GraphManager

if TYPE_CHECKING:
    from checkov.common.typing import LibraryGraphConnector


class ArmGraphManager(GraphManager[ArmLocalGraph, "dict[str, dict[str, Any]]"]):
    def __init__(self, db_connector: LibraryGraphConnector, source: str = GraphSource.ARM) -> None:
        super().__init__(db_connector=db_connector, parser=None, source=source)

    def build_graph_from_source_directory(
        self,
        source_dir: str,
        local_graph_class: type[ArmLocalGraph] = ArmLocalGraph,
        render_variables: bool = False,
        parsing_errors: dict[str, Exception] | None = None,
        download_external_modules: bool = False,
        excluded_paths: list[str] | None = None,
    ) -> tuple[ArmLocalGraph, dict[str, dict[str, Any]]]:
        file_paths = get_scannable_file_paths(root_folder=source_dir, excluded_paths=excluded_paths)
        filepath_fn = lambda f: f"/{os.path.relpath(f, os.path.commonprefix((source_dir, f)))}"
        definitions, _, _ = get_files_definitions(files=file_paths, filepath_fn=filepath_fn)

        local_graph = self.build_graph_from_definitions(definitions=definitions)

        return local_graph, definitions

    def build_graph_from_definitions(
        self, definitions: dict[str, dict[str, Any]], render_variables: bool = True
    ) -> ArmLocalGraph:
        local_graph = ArmLocalGraph(definitions=definitions)
        local_graph.build_graph(render_variables=render_variables)

        return local_graph



from __future__ import annotations

from typing import List, Dict, Any, Union, TYPE_CHECKING

from checkov.terraform.checks.data.base_cloudsplaining_data_iam_check import BaseTerraformCloudsplainingDataIAMCheck

if TYPE_CHECKING:
    from cloudsplaining.scan.policy_document import PolicyDocument


class CloudSplainingPermissionsManagement(BaseTerraformCloudsplainingDataIAMCheck):
    def __init__(self) -> None:
        name = "Ensure IAM policies does not allow permissions management / resource exposure without constraints"
        id = "CKV_AWS_109"
        super().__init__(name=name, id=id)

    def cloudsplaining_analysis(self, policy: PolicyDocument) -> Union[List[str], List[Dict[str, Any]]]:
        return policy.permissions_management_without_constraints


check = CloudSplainingPermissionsManagement()



from __future__ import annotations

import logging
from typing import TYPE_CHECKING, Any

from checkov.arm.graph_builder.graph_components.block_types import BlockType
from checkov.common.graph.graph_builder import Edge
from checkov.common.graph.graph_builder.utils import adjust_value
from checkov.common.graph.graph_builder.variable_rendering.renderer import VariableRenderer
from checkov.common.util.data_structures_utils import pickle_deepcopy

if TYPE_CHECKING:
    from checkov.arm.graph_builder.local_graph import ArmLocalGraph


class ArmVariableRenderer(VariableRenderer["ArmLocalGraph"]):
    def __init__(self, local_graph: ArmLocalGraph) -> None:
        super().__init__(local_graph)

    def _render_variables_from_vertices(self) -> None:
        # need to add rendering to function like format, reference etc
        pass

    def evaluate_vertex_attribute_from_edge(self, edge_list: list[Edge]) -> None:
        origin_vertex_attributes = self.local_graph.vertices[edge_list[0].origin].attributes
        val_to_eval = pickle_deepcopy(origin_vertex_attributes.get(edge_list[0].label, ""))
        attr_path = None
        for edge in edge_list:
            attr_path, attr_value = self.extract_dest_attribute_path_and_value(dest_index=edge.dest,
                                                                               origin_value=val_to_eval)
            '''if the arg start with '[parameters'/ '[variables' its mean we need to eval the all attribute
            like here - "addressPrefix": "[parameters('subnetAddressPrefix')]" '''
            if len(edge_list) == 1 and isinstance(val_to_eval, str) and val_to_eval.startswith(("[parameters", "[variables")):
                val_to_eval = attr_value
                continue
            '''
            if the value i need to eval is part of the full attribute like "[format('{0}/{1}', parameters('vnetName'), variables('subnetName'))]"
            or "[resourceId('Microsoft.Network/networkProfiles', variables('networkProfileName'))]".
            vertices[edge.dest].id = variables.networkProfileName -> variables('networkProfileName')
            '''
            val_to_replace = self.local_graph.vertices[edge.dest].id.replace(".", "('") + "')"
            if attr_value and isinstance(val_to_eval, str):
                val_to_eval = val_to_eval.replace(val_to_replace, str(attr_value))

        self.local_graph.update_vertex_attribute(
            vertex_index=edge_list[0].origin,
            attribute_key=edge_list[0].label,
            attribute_value=val_to_eval,
            change_origin_id=edge_list[0].dest,
            attribute_at_dest=attr_path,
        )

    def extract_dest_attribute_path_and_value(self, dest_index: int, origin_value: Any) -> tuple[str, Any] | tuple[None, None]:
        vertex = self.local_graph.vertices[dest_index]
        if vertex.block_type == BlockType.PARAMETER:
            new_value = vertex.attributes.get("defaultValue")
            if new_value:
                new_value = adjust_value(element_name=origin_value, value=new_value)
                return "defaultValue", new_value
            else:
                logging.warning(f'No defaultValue for parameter id = {vertex.id}')
                return "defaultValue", origin_value
        elif vertex.block_type == BlockType.VARIABLE:
            new_value = adjust_value(element_name=origin_value, value=vertex.attributes.get("value"))
            return "value", new_value
        return None, None

    def evaluate_non_rendered_values(self) -> None:
        pass



import fnmatch
import logging
from abc import ABC
from typing import Dict, List, Any, Union

from cloudsplaining.scan.policy_document import PolicyDocument

from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.data.base_check import BaseDataCheck
from checkov.terraform.checks.utils.base_cloudsplaining_iam_scanner import BaseTerraformCloudsplainingIAMScanner
from checkov.terraform.checks.utils.iam_terraform_document_to_policy_converter import (
    convert_terraform_conf_to_iam_policy,
)


class BaseTerraformCloudsplainingDataIAMCheck(BaseDataCheck, BaseTerraformCloudsplainingIAMScanner, ABC):
    def __init__(self, name: str, id: str) -> None:
        super().__init__(name=name, id=id, categories=[CheckCategories.IAM], supported_data=["aws_iam_policy_document"])

    def scan_data_conf(self, conf: Dict[str, List[Any]]) -> CheckResult:
        return self.scan_conf(conf)

    @property
    def cache_key(self) -> str:
        return self.entity_path

    def should_scan_conf(self, conf: Dict[str, List[Any]]) -> bool:
        return "statement" in conf.keys()

    def convert_to_iam_policy(self, conf: Dict[str, List[Any]]) -> PolicyDocument:
        converted_conf = convert_terraform_conf_to_iam_policy(conf)
        return PolicyDocument(converted_conf)

    def cloudsplaining_enrich_evaluated_keys(self, policy: PolicyDocument,
                                             violating_actions: Union[List[str], List[Dict[str, Any]]]) -> None:
        try:
            # in case we have violating actions for this policy we start looking for it through the statements
            for stmt_idx, statement in enumerate(policy.statements):
                actions = statement.statement.get('Action')  # get the actions for this statement
                if actions:
                    if isinstance(actions, str):
                        for violating_action in violating_actions:
                            if fnmatch.fnmatch(violating_action.lower(), actions.lower()):  # found the violating action in our list of actions
                                self.evaluated_keys.append(f"statement/[{stmt_idx}]/actions")
                                return
                    if isinstance(actions, list):
                        for action in actions:      # go through the actions of this statement and try to match one violation
                            for violating_action in violating_actions:
                                if isinstance(action, str) and fnmatch.fnmatch(violating_action.lower(), action.lower()):      # found the violating action in our list of actions
                                    self.evaluated_keys.append(f"statement/[{stmt_idx}]/actions")
                                    return
        except Exception as e:
            logging.warning(f'Failed enriching cloudsplaining evaluated keys due to: {e}')



from __future__ import annotations
from typing import Any
from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.arm.base_resource_check import BaseResourceCheck
from typing import Optional


class AKSMaxPodsMinimum(BaseResourceCheck):
    def __init__(self) -> None:
        name = "Ensure Azure Kubernetes Cluster (AKS) nodes should use a minimum number of 50 pods."
        id = "CKV_AZURE_168"
        supported_resources = ("Microsoft.ContainerService/managedClusters",
                               "Microsoft.ContainerService/managedClusters/agentPools", )
        categories = (CheckCategories.KUBERNETES,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,)

    def scan_resource_conf(self, conf: dict[str, Any]) -> CheckResult:
        max_pods: Optional[int] = 30

        properties = conf.get("properties")
        if properties and isinstance(properties, dict):
            max_pods = properties.get("maxPods")

        if "agentPoolProfiles" in properties:
            if "maxPods" in properties["agentPoolProfiles"][0]:
                max_pods = properties["agentPoolProfiles"][0]["maxPods"]

        if max_pods is None or max_pods < 50:
            return CheckResult.FAILED

        return CheckResult.PASSED


check = AKSMaxPodsMinimum()



from checkov.arm.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories


class AppServiceSlotHTTPSOnly(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure web app redirects all HTTP traffic to HTTPS in Azure App Service Slot"
        id = "CKV_AZURE_153"
        supported_resources = ("Microsoft.Web/sites", "Microsoft.Web/sites/slots",)
        categories = (CheckCategories.NETWORKING,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "properties/httpsOnly"


check = AppServiceSlotHTTPSOnly()



from checkov.common.models.enums import CheckCategories, CheckResult
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class WinVMAutomaticUpdates(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure Windows VM enables automatic updates"
        id = "CKV_AZURE_177"
        supported_resources = ("Microsoft.Compute/virtualMachines", "Microsoft.Compute/virtualMachineScaleSets")
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.PASSED,)

    def get_inspected_key(self) -> str:
        if self.entity_type == "Microsoft.Compute/virtualMachineScaleSets":
            return "properties/virtualMachineProfile/osProfile/windowsConfiguration/enableAutomaticUpdates"
        return "properties/osProfile/windowsConfiguration/enableAutomaticUpdates"


check = WinVMAutomaticUpdates()



from __future__ import annotations

import os
from pathlib import Path
from typing import Any, TYPE_CHECKING

from checkov.arm.utils import ArmElements

if TYPE_CHECKING:
    from checkov.arm.graph_builder.graph_components.blocks import ArmBlock


def convert_graph_vertices_to_definitions(vertices: list[ArmBlock], root_folder: str | Path | None)\
        -> tuple[dict[str, dict[str, Any]], dict[str, dict[str, Any]]]:
    arm_definitions: dict[str, dict[str, Any]] = {}
    breadcrumbs: dict[str, dict[str, Any]] = {}
    for vertex in vertices:
        block_path = vertex.path
        arm_element = vertex.block_type
        element_name = vertex.name
        if arm_element == ArmElements.RESOURCES:
            arm_definitions.setdefault(block_path, {}).setdefault(arm_element, []).append(vertex.config)
        else:
            arm_definitions.setdefault(block_path, {}).setdefault(arm_element, {})[element_name] = vertex.config

        if vertex.breadcrumbs:
            relative_block_path = f"/{os.path.relpath(block_path, root_folder)}"
            add_breadcrumbs(vertex, breadcrumbs, relative_block_path)
    return arm_definitions, breadcrumbs


def add_breadcrumbs(vertex: ArmBlock, breadcrumbs: dict[str, dict[str, Any]], relative_block_path: str) -> None:
    breadcrumbs.setdefault(relative_block_path, {})[vertex.name] = vertex.breadcrumbs



from checkov.common.models.enums import CheckCategories
from checkov.arm.base_resource_value_check import BaseResourceValueCheck


class MariaDBGeoBackupEnabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure that MariaDB server enables geo-redundant backups"
        id = "CKV_AZURE_129"
        supported_resources = ("Microsoft.DBforMariaDB/servers",)
        categories = (CheckCategories.BACKUP_AND_RECOVERY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "properties/storageProfile/geoRedundantBackup"

    def get_expected_value(self) -> str:
        return "Enabled"


check = MariaDBGeoBackupEnabled()




from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck
from typing import Any


class AppConfigSku(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure App configuration Sku is standard"
        id = "CKV_AZURE_188"
        supported_resources = ("azurerm_app_configuration",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "sku"

    def get_expected_value(self) -> Any:
        return "standard"


check = AppConfigSku()



from checkov.common.models.enums import CheckResult, CheckCategories
from checkov.terraform.checks.resource.base_resource_check import BaseResourceCheck


class SynapseWorkspaceAdministratorLoginPasswordHidden(BaseResourceCheck):
    def __init__(self):
        name = "Ensure Azure Synapse Workspace administrator login password is not exposed"
        id = "CKV_AZURE_239"
        supported_resources = ['azurerm_synapse_workspace']
        categories = [CheckCategories.SECRETS]
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def scan_resource_conf(self, conf):
        if 'sql_administrator_login_password' in conf:
            return CheckResult.FAILED
        return CheckResult.PASSED


check = SynapseWorkspaceAdministratorLoginPasswordHidden()



from checkov.arm.base_resource_value_check import BaseResourceValueCheck
from checkov.common.models.enums import CheckCategories, CheckResult


class AppServiceSlotDebugDisabled(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure debugging is disabled for the App service slot"
        id = "CKV_AZURE_155"
        supported_resources = ('Microsoft.Web/sites/slots', 'Microsoft.Web/sites',)
        categories = (CheckCategories.NETWORKING,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources,
                         missing_block_result=CheckResult.PASSED)

    def get_inspected_key(self) -> str:
        return "properties/siteConfig/remoteDebuggingEnabled"

    def get_expected_value(self) -> bool:
        return False


check = AppServiceSlotDebugDisabled()



from __future__ import annotations

from typing import Any

from checkov.common.models.enums import CheckResult
from checkov.github.base_github_org_check import BaseOrganizationCheck


class GithubPrivateRepositoryCreationIsLimited(BaseOrganizationCheck):
    def __init__(self) -> None:
        name = "Ensure private repository creation is limited to specific members"
        id = "CKV_GITHUB_22"
        super().__init__(id=id, name=name, missing_attribute_result=CheckResult.FAILED)

    def get_evaluated_keys(self) -> list[str]:
        return ["members_can_create_private_repositories"]

    def get_allowed_values(self) -> list[Any]:
        return [False]


check = GithubPrivateRepositoryCreationIsLimited()



from checkov.common.models.enums import CheckCategories
from checkov.terraform.checks.resource.base_resource_value_check import BaseResourceValueCheck


class AkSSecretStoreRotation(BaseResourceValueCheck):
    def __init__(self) -> None:
        name = "Ensure autorotation of Secrets Store CSI Driver secrets for AKS clusters"
        id = "CKV_AZURE_172"
        supported_resources = ("azurerm_kubernetes_cluster",)
        categories = (CheckCategories.GENERAL_SECURITY,)
        super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)

    def get_inspected_key(self) -> str:
        return "key_vault_secrets_provider/secret_rotation_enabled"


check = AkSSecretStoreRotation()
